@@ -108,7 +108,7 @@ class Obraz(Mail_sender):
         self._fast_book.append(text)
     self.book = self._fast_book
     print("В библиотеке ", i, " текстов, где есть хотя бы одно из буквосочетаний ", str(keys))
-    self._fast_print(str(keys), 'or')
+    self._fast_print(keys, 'or')
 
 
   def fast_and(self):
@@ -130,7 +130,63 @@ class Obraz(Mail_sender):
         self._fast_book.append(text)
     self.book = self._fast_book
     print("В библиотеке ", i, " текстов, где в каждом есть все буквосочетания ", str(keys))
-    self._fast_print(str(keys), 'and')
+    self._fast_print(keys, 'and')
+
+  def fast_or_re(self):
+    """ В self.book проводится поиск буквосочетаний и тексты, где есть буквосочетания, те тексты оставляются. Остальные - удаляются
+    """
+    keys = [key for key in input("Режим Fast. Введите через пробел те буквосочетания, которые должны быть в богослужебном тексте: ").split()]
+    i = 0
+    self._fast_book = []
+    pattern = r''
+    for key in keys:
+      if key[0] == "_":
+        key = r'[^а-яА-Я]'+key[1:]
+      if key[-1] == "_":
+        key = key[:-1]+r'[^а-яА-Я]'
+      key += '|'
+      pattern += key
+    pattern = pattern[:-1]
+      
+    for text in self.book:
+      y = False
+      if re.search(pattern, " "+text[0].upper()+" "):
+        y = True
+      if y:
+        i += 1
+        self._fast_book.append(text)
+    self.book = self._fast_book
+    print("В библиотеке ", i, " текстов, где есть хотя бы одно из буквосочетаний ", str(keys))
+    self._fast_print(keys, 'or')
+
+
+  def fast_and_re(self):
+    """ В self.book проводится поиск буквосочетаний и тексты, где есть буквосочетания, те тексты оставляются. Остальные - удаляются
+    """
+    keys = [key for key in input("Режим Fast. Введите через пробел те буквосочетания, которые должны быть в богослужебном тексте: ").split()]
+    i = 0
+    self._fast_book = []
+    patterns = []
+    for key in keys:
+      key = key.upper()
+      if key[0] == "_":
+        key = r'[^а-яА-Я]'+key[1:]
+      if key[-1] == "_":
+        key = key[:-1]+r'[^а-яА-Я]'
+      patterns.append(key)
+      
+
+    for text in self.book:
+      y = True
+      for pattern in patterns:
+        if not re.search(pattern, " "+text[0].upper()+" "):
+          y = False
+      if y:
+        i += 1
+        self._fast_book.append(text)
+    self.book = self._fast_book
+    print("В библиотеке ", i, " текстов, где в каждом есть все буквосочетания ", str(keys))
+    self._fast_print(keys, 'and')
   
 
   def results(self):
@@ -423,7 +479,7 @@ class Obraz(Mail_sender):
         email = self.email   
       else:       
         email = input("Введите ваш email: ")
-      self._send_to_email_docx_fast_book(keys=keys, mode=mode, email=email)
+      self._send_to_email_docx_fast_book(keys_=keys, mode=mode, email=email)
 
 
 
